==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/plugins/Output/oss/translations/oss_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>Модуль OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>О модуле вывода OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Модуль вывода OSS для Qmmp</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Разработчик: Юрий Журавлёв &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>Настройки модуля OSS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="30"/>
        <source>Device Settings</source>
        <translation>Настройки устройства</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Audio device</source>
        <translation>Аудиоустройство</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Mixer device</source>
        <translation>Устройство микшера</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Advanced Settings</source>
        <translation>Дополнительные настройки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Soundcard</source>
        <translation>Звуковая карта</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Buffer time (ms):</source>
        <translation>Время буфера (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="167"/>
        <source>Period time (ms):</source>
        <translation>Время периода (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>PCM over Master</source>
        <translation>PCM вместо Master</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="224"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="231"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Output/oss/translations/oss_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="37"/>
        <source>OSS Plugin</source>
        <translation>Модуль OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>About OSS Output Plugin</source>
        <translation>О модуле вывода OSS</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Модуль вывода OSS для Qmmp</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Разработчик: Юрий Журавлёв &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="60"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>Основано на коде Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>Настройки модуля OSS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Настройки устройства</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Аудиоустройство</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer device</source>
        <translation>Устройство микшера</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Advanced Settings</source>
        <translation>Дополнительные настройки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Soundcard</source>
        <translation>Звуковая карта</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Buffer time (ms):</source>
        <translation>Время буфера (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="170"/>
        <source>Period time (ms):</source>
        <translation>Время периода (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="200"/>
        <source>PCM over Master</source>
        <translation>PCM вместо Master</translation>
    </message>
</context>
</TS>
